django-fretboard
================

Django-Fretboard is a fork of the forums used on gretschpages.com/forum/

It is built for Django 1.5, and is not compatible with previous versions of Django.


### Settings
There are a few settings you may wish to override:

* PAGINATE_BY: defaults to 25 
* FORUM_BASE_NAME: defaults to site name
* COMMENT_PLACEHOLDER: placeholder text for post box.


### Requirements:

[Tango Shared Core](https://github.com/tBaxter/tango-shared-core) is used for standardizing images and allows for voting.
